==> netty-incubator-codec-bhttp-0.0.13.Final-sources.jar: io/netty/incubator/codec/bhttp/DefaultBinaryHttpResponse.java <==
/*
 * Copyright 2023 The Netty Project
 *
 * The Netty Project licenses this file to you under the Apache License,
 * version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at:
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */
package io.netty.incubator.codec.bhttp;

import io.netty.handler.codec.http.DefaultHttpResponse;
import io.netty.handler.codec.http.HttpResponseStatus;
import io.netty.handler.codec.http.HttpVersion;

/**
 * {@link DefaultHttpResponse} for
 * <a href="https://www.rfc-editor.org/rfc/rfc9292.html">Binary Representation of HTTP Messages</a>.
 */
public final class DefaultBinaryHttpResponse extends DefaultHttpResponse implements BinaryHttpResponse {
    public DefaultBinaryHttpResponse(HttpVersion version, HttpResponseStatus status) {
        super(version, status, BinaryHttpHeaders.newHeaders(true));
    }

    public DefaultBinaryHttpResponse(HttpVersion version, HttpResponseStatus status, boolean validateHeaders) {
        super(version, status, BinaryHttpHeaders.newHeaders(validateHeaders));
    }

    DefaultBinaryHttpResponse(HttpVersion version, HttpResponseStatus status, BinaryHttpHeaders headers) {
        super(version, status, headers);
    }

    @Override
    public BinaryHttpResponse setStatus(HttpResponseStatus status) {
        super.setStatus(status);
        return this;
    }

    @Override
    public BinaryHttpResponse setProtocolVersion(HttpVersion version) {
        super.setProtocolVersion(version);
        return this;
    }

    @Override
    public int hashCode() {
        return super.hashCode();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        return super.equals(o);
    }
}

==> netty-incubator-codec-bhttp-0.0.16.Final-sources.jar: io/netty/incubator/codec/bhttp/DefaultBinaryHttpResponse.java <==
/*
 * Copyright 2023 The Netty Project
 *
 * The Netty Project licenses this file to you under the Apache License,
 * version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at:
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */
package io.netty.incubator.codec.bhttp;

import io.netty.handler.codec.http.DefaultHttpResponse;
import io.netty.handler.codec.http.HttpResponseStatus;
import io.netty.handler.codec.http.HttpVersion;

/**
 * {@link DefaultHttpResponse} for
 * <a href="https://www.rfc-editor.org/rfc/rfc9292.html">Binary Representation of HTTP Messages</a>.
 */
public final class DefaultBinaryHttpResponse extends DefaultHttpResponse implements BinaryHttpResponse {
    public DefaultBinaryHttpResponse(HttpVersion version, HttpResponseStatus status) {
        this(version, status, BinaryHttpHeaders.newHeaders(true));
    }

    public DefaultBinaryHttpResponse(HttpVersion version, HttpResponseStatus status, boolean validateHeaders) {
        this(version, status, BinaryHttpHeaders.newHeaders(validateHeaders));
    }

    DefaultBinaryHttpResponse(HttpVersion version, HttpResponseStatus status, BinaryHttpHeaders headers) {
        super(version, status, headers);
    }

    @Override
    public BinaryHttpResponse setStatus(HttpResponseStatus status) {
        super.setStatus(status);
        return this;
    }

    @Override
    public BinaryHttpResponse setProtocolVersion(HttpVersion version) {
        super.setProtocolVersion(version);
        return this;
    }

    @Override
    public int hashCode() {
        return super.hashCode();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        return super.equals(o);
    }
}
